@@ -9,6 +9,8 @@ import requests
 import os
 import sys
 from datetime import datetime
+import socket
+from uuid import getnode
 
 import ttkbootstrap as ttk
 from ttkbootstrap.constants import *
@@ -19,12 +21,15 @@ from ttkbootstrap.toast import ToastNotification
 
 if __package__:
     from .toastx import ToastNotificationX
+    from .waiting_frame import WaitingFrame
 else:
     ROOT = os.path.dirname(__file__)
     if ROOT not in sys.path:
         sys.path.append(ROOT)
     from toastx import ToastNotificationX
+    from waiting_frame import WaitingFrame
 
+UPLOAD_URL = 'http://zhangys.org.cn/home/upload'
 USE_PROGRESSBAR = False
 USE_GRID_LAYOUT = False
 DEFAULT_WINSIZE = '500x400'
@@ -366,31 +371,44 @@ class FileSearchFrame(ttk.Frame):
 
         curItem = self.get_current_selection()
         if curItem:          
-            imgpath = self.resultview.item(curItem, 'values')[4]
-            self.send_data_to_server(imgpath, {'operator':'zys','timestamp': datetime.now()})
-        
-    def send_data_to_server(self, image_path, metadata):
+            imgpath = self.resultview.item(curItem, 'values')[4]            
+            h_name = socket.gethostname()
+            IP_addres = socket.gethostbyname(h_name)            
+            mac = getnode()
             
+            wapp = ttk.Toplevel(title='Uploading...', size=(300,50))
+            wframe = WaitingFrame(wapp)
+            wframe.task_to_run = lambda: self.send_data_to_server(wframe, imgpath, {'IP':IP_addres, 'MAC':mac, 'operator':'zys','timestamp': datetime.now()})
+            wframe.start_task()
+
+    def send_data_to_server(self, frame, image_path, metadata):
+        
         image_filename = os.path.basename(image_path)    
         multipart_form_data = {
-            'image': (image_filename, open(image_path, 'rb')),
-            'metadata': ('', str(metadata)),
+            'image': (image_filename, open(image_path, 'rb'))
         }
 
-        if self.master.attributes('-fullscreen'):
+        try: # to handle network down exception, etc.
+            r = requests.post(UPLOAD_URL, 
+            files=multipart_form_data, data=metadata)
+            title = 'HTTP Status Code ' + str(r.status_code)
+            message = r.text
+            # frame.message.set( + '\n' + r.text)
+        except Exception as e:
+            title = 'Exception'
+            message = str(e)
+
+        WaitingFrame.threadqueue.task_done()
+        
+        if True: # self.master.attributes('-fullscreen'):
             toast = ToastNotification(
-                title='Upload to Server',
-                message=str(multipart_form_data), 
-                duration=1000,
+                title=title,
+                message=message, 
+                duration=2000,
             )
             toast.show_toast()
         else:
-            Messagebox.show_info(str(multipart_form_data), 'Upload to Server')
-        
-        return    
-        response = requests.post('http://www.example.com/api/v1/sensor_data/',
-                                files=multipart_form_data)    
-        print(response.status_code)
+            Messagebox.show_info(message, title) # cannot do this in a sub thread
 
     def on_browse(self):
         """Callback for directory browse"""
